#!/usr/bin/python
# This is the Python GI version of test-glib-simple-items.c

import gobject
from gi.repository import Dbusmenu

dummies = ['Bob', 'Jim', 'Alvin', 'Mary']

def dummy_users(root):
    count = 0
    for user in dummies:
        mi = Dbusmenu.Menuitem()
        print 'Creating item: %d %s' % (mi.get_id(), user)
        print '\tRoot ID:', root.get_id()
        mi.property_set('label', user)
        root.child_add_position(mi, count)
        assert mi.property_get('label') == user
        count += 1

def quititall(mainloop):
    mainloop.quit()
    return False

# main

server = Dbusmenu.Server.new('/test/object')
root_menuitem = Dbusmenu.Menuitem()
server.set_root(root_menuitem)
print 'Root ID:', root_menuitem.get_id()

dummy_users(root_menuitem)

mainloop = gobject.MainLoop()
gobject.timeout_add_seconds(1, quititall, mainloop)
mainloop.run()



#!/usr/bin/python

# A test for libdbusmenu to ensure its quality. This is the Python GI version
# of test-gtk-shortcut-client.c
#
# Copyright 2011 Canonical Ltd.
# Authors:
#   Martin Pitt <martin.pitt@ubuntu.com>

import sys
import gobject
from gi.repository import Gtk, DbusmenuGtk
Gtk.require_version('2.0')

passed = True
main_loop = gobject.MainLoop()

def timer_func(data):
    passed = True
    main_loop.quit()
    return False

# main
print 'Building Window'
window = Gtk.Window(type=Gtk.WindowType.TOPLEVEL)
menubar = Gtk.MenuBar()
menuitem = Gtk.MenuItem(label='Test')

dmenu = DbusmenuGtk.Menu(dbus_name='glib.label.test', dbus_object='/org/test')
dclient = dmenu.get_client()
agroup = Gtk.AccelGroup()
dclient.set_accel_group(agroup)

menuitem.set_submenu(dmenu)
menuitem.show()
menubar.append(menuitem)
menubar.show()
window.add(menubar)
window.set_title('libdbusmenu-gtk test')
window.add_accel_group(agroup)
window.show_all()

gobject.timeout_add_seconds(10, timer_func, window)

print 'Entering Mainloop'
main_loop.run()

if passed:
    print 'Quiting'
else:
    print "Quiting as we're a failure"
    sys.exit(1)



from mago.test_suite.main import SingleApplicationTestSuite 
from mago.application.main import Application 

import ldtp, ooldtp, ldtputils, os.path

class DbusMenuGtkApp():
    LAUNCHER = os.path.join(os.path.dirname(__file__), "..", "dbusMenuTest")
    WINDOW   = "frmlibdbusmenu-gtktest"

    def open(self, menu_schema=''):
        ldtp.launchapp(self.LAUNCHER, [menu_schema])

    def menu_exists(self, menu=''):
        app = ooldtp.context(self.WINDOW)

        if menu == '':
            menu = "mnu1"

        try:
            component = app.getchild(menu)
        except ldtp.LdtpExecutionError:
            return False

        return True
    
    def get_submenus(self, menu=''):
        app = ooldtp.context(self.WINDOW)

        if menu == '':
            menu = "mnu1"

        component = app.getchild(menu)

        try:
            submenus = component.listsubmenus()
        except ldtp.LdtpExecutionError:
            return "" 
        
        return submenus

class DbusMenuGtkTest(SingleApplicationTestSuite):
    APPLICATION_FACTORY = DbusMenuGtkApp

    def cleanup(self):
        ldtp.waittillguinotexist(self.application.WINDOW, guiTimeOut=70)

    def teardown(self):
        ldtp.waittillguinotexist(self.application.WINDOW, guiTimeOut=70)

    def testStaticMenu(self, menu_schema, menu_item='', notexists=''):
        self.application.open(menu_schema)
        ldtp.waittillguiexist(self.application.WINDOW)

        if notexists == "True":
            if self.application.menu_exists(menu_item):
                raise AssertionError("The menu item exists")
        else:
            if not self.application.menu_exists(menu_item):
                raise AssertionError("The menu item does not exists")


    def testSubmenus(self, menu_schema, menu_item='', submenus=''):
        self.application.open(menu_schema)
        ldtp.waittillguiexist(self.application.WINDOW)

        if submenus != self.application.get_submenus(menu_item):
            raise AssertionError("The submenus are different")


         

